@@ -1,4 +1,5 @@
 import typing
+from http import HTTPStatus
 
 if typing.TYPE_CHECKING:
     import aiohttp
@@ -11,11 +12,11 @@ __all__ = ("HTTPError",)
 class HTTPError(Exception):
     def __init__(self, status_code: int, reason: str, data):
         self.status_code: int = status_code
-        self.reason: str = reason
+        self.reason: str = reason or HTTPStatus(status_code).phrase
         self.data = data
 
     def __str__(self):
-        return f"HTTPError: {self.status_code}: {self.reason}, {self.data!r}"
+        return f"HTTPError: {self.status_code} {self.reason}, {self.data!r}"
 
     def __repr__(self):
         return f"{self.__class__.__name__}({self.status_code}, {self.reason!r})"
@@ -31,7 +32,7 @@ class HTTPError(Exception):
     @classmethod
     def from_aiohttp(
         cls, http_error: "aiohttp.ClientResponseError", data
-    ) -> "HTTPError":  # pragma: no cover
+    ) -> "HTTPError":
         status_code = http_error.status
         reason = http_error.message
         return cls(status_code, reason, data)
